@@ -23,7 +23,7 @@ use strict;
 use integer;
 use vars qw($VERSION);
 
-$VERSION = "1.31";
+$VERSION = "1.32";
 
 # ---======================= Public Methods ======================---
 
@@ -251,7 +251,7 @@ sub _format_line {
     my $height = 0;
     my @col_lines;
     for (@$columns) {
-        my @lines = split "\n" => ($_ || '');
+        my @lines = split "\n", (defined $_ ? $_ : '');
         $height = scalar @lines
             if $height < @lines;
         push @col_lines, \@lines;
@@ -276,7 +276,7 @@ sub _format_line {
 sub _column_length
 {
     my ($str) = @_;
-    $str ||= '';
+    $str = '' unless defined $str;
 
     my $len = 0;
     for (split "\n", $str) {
@@ -552,8 +552,9 @@ feedback, or good karma:
     Prakash Kailasa
     Slaven Rezic
     Harlan Lieberman-Berg
+    Patrick Kuijvenhoven
 
 =head1 VERSION
 
-This documentation describes C<Text::TabularDisplay> version 1.30.
+This documentation describes C<Text::TabularDisplay> version 1.32.
 
